@@ -78,7 +78,7 @@ public class DefaultGisViewerServiceImpl extends GisViewerServiceImpl {
 			}
 			
 			@Override
-			public String getWmsURL() {
+			public String getWmsServiceBaseURL() {
 				return layerWmsUrl;
 			}
 			
